# HeavyEdge-Features

[![Supported Python Versions](https://img.shields.io/pypi/pyversions/heavyedge-features.svg)](https://pypi.python.org/pypi/heavyedge-features/)
[![PyPI Version](https://img.shields.io/pypi/v/heavyedge-features.svg)](https://pypi.python.org/pypi/heavyedge-features/)
[![License](https://img.shields.io/github/license/heavyedge/heavyedge-features)](https://github.com/heavyedge/heavyedge-features/blob/master/LICENSE)
[![CI](https://github.com/heavyedge/heavyedge-features/actions/workflows/ci.yml/badge.svg)](https://github.com/heavyedge/heavyedge-features/actions/workflows/ci.yml)
[![CD](https://github.com/heavyedge/heavyedge-features/actions/workflows/cd.yml/badge.svg)](https://github.com/heavyedge/heavyedge-features/actions/workflows/cd.yml)
[![Docs](https://readthedocs.org/projects/heavyedge-features/badge/?version=latest)](https://heavyedge-features.readthedocs.io/en/latest/?badge=latest)

Quantify global and local shape features from edge profiles

## Usage

## Installation

```
$ pip install heavyedge-features
```

## Documentation

The manual can be found online:

> https://heavyedge-features.readthedocs.io

If you want to build the document yourself, get the source code and install with `[doc]` dependency.
Then, go to `doc` directory and build the document:

```
$ pip install .[doc]
$ cd doc
$ make html
```

Document will be generated in `build/html` directory. Open `index.html` to see the central page.

## Developing

### Installation

For development features, you must install the package by `pip install -e .[dev]`.

### Testing

Run `pytest` command to perform unit test.

When doctest is run, buildable sample data are rebuilt by default.
To disable this, set `HEAVYEDGE_TEST_REBUILD` environment variable to zero.
For example,
```
HEAVYEDGE_TEST_REBUILD=0 pytest
```
